@@ -8,8 +8,8 @@ import os
 import sys
 import time
 
-startup_debug = os.environ.get("FastTracker.Debug", "off").lower() in ("on", "true", "1")
-fast_debug_level = int(os.environ.get("FastTracker.Debug.Level", "0"))
+startup_debug = os.environ.get("FastTracker_Debug", "off").lower() in ("on", "true", "1")
+fast_debug_level = int(os.environ.get("FastTracker_Debug_Level", "0"))
 
 
 def log_message(text, *args, level=1):
